@@ -25,6 +25,11 @@ import com.milaboratory.core.sequence.Sequence;
  * @param <S> type of the sequence
  */
 public interface SequenceProvider<S extends Sequence<S>> {
+    /**
+     * Forces all underlying providers to be materialized
+     */
+    void forceInitialize();
+
     /**
      * Returns the length of the sequence this object represents.
      *
